@@ -10,6 +10,7 @@ __PACKAGE__->attributes(qw/name code properties/);
 
 use Dancer::Factory::Hook;
 use Dancer::Hook::Properties;
+use Dancer::Exception qw(:all);
 
 sub new {
     my ($class, @args) = @_;
@@ -17,7 +18,7 @@ sub new {
     my $self = bless {}, $class;
 
     if (!scalar @args) {
-        croak "one name and a coderef are required";
+        raise core_hook => "one name and a coderef are required";
     }
 
     my $hook_name = shift @args;
@@ -41,26 +42,23 @@ sub new {
         $code       = shift @args;
     }
     else {
-        croak "something's wrong";
+        raise core_hook => "something's wrong with parameters passed to Hook constructor";
     }
+    ref $code eq 'CODE'
+      or raise core_hook => "the code argument passed to hook construction was not a CodeRef. Value was : '$code'";
+
 
     my $compiled_filter = sub {
+        my @arguments = @_;
         return if Dancer::SharedData->response->halted;
 
         my $app = Dancer::App->current();
         return unless $properties->should_run_this_app($app->name);
 
         Dancer::Logger::core( "entering " . $hook_name . " hook" );
-        eval { $code->(@_) };
 
-        if ($@) {
-            my $err = Dancer::Error->new(
-                code    => 500,
-                title   => $hook_name . ' filter error',
-                message => "An error occured while executing the filter named $hook_name: $@"
-            );
-            return Dancer::halt( $err->render );
-        }
+        $code->(@arguments);
+
     };
 
     $self->properties($properties);
@@ -108,7 +106,7 @@ Currently supported properties:
 
 =head2 register_hooks_name
 
-Add a new hook name, so developpers of application can insert some code at this point.
+Add a new hook name, so application developers can insert some code at this point.
 
     package My::Dancer::Plugin;
     Dancer::Hook->instance->register_hooks_name(qw/before_auth after_auth/);
